@@ -1,5 +1,5 @@
 package Test::Sys::Info::Driver;
-$Test::Sys::Info::Driver::VERSION = '0.22';
+$Test::Sys::Info::Driver::VERSION = '0.23';
 use strict;
 use warnings;
 
@@ -18,7 +18,11 @@ use constant DRIVER_MODULES => (
 sub new {
     my $class = shift;
     my $id    = shift || croak 'Driver ID is missing';
-    my @suite = map { sprintf $_, $id } DRIVER_MODULES;
+    my @suite = map {
+        my $name = $_;
+        $name =~ m{ \%s }xms ? sprintf( $name, $id ) : $name;
+    } DRIVER_MODULES;
+
     foreach my $module ( @suite ) {
         require_ok( $module );
         ok( $module->import || 1, "$module imported" );
@@ -142,7 +146,7 @@ Test::Sys::Info::Driver
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
